@@ -81,6 +81,9 @@ class Const(object):
     CONFIG_SECTION_ENFORCE = 'environment:enforce'
     DIALOG_DIALECT_MACHINE = 'machine'
     DIALOG_DIALECT_HUMAN = 'human'
+    EXIT_CODE_SUCCESS = 0
+    EXIT_CODE_GENERAL_ERROR = 1
+    EXIT_CODE_INITIALIZATION_ERROR = 2
 
 
 @util.export
@@ -99,6 +102,7 @@ class BaseEnv(object):
     ERROR = 'BASE/error'
     ABORTED = 'BASE/aborted'
     EXCEPTION_INFO = 'BASE/exceptionInfo'
+    EXIT_CODE = 'BASE/exitCode'
     LOG = 'BASE/log'
     PLUGIN_PATH = 'BASE/pluginPath'
     PLUGIN_GROUPS = 'BASE/pluginGroups'
@@ -166,12 +170,16 @@ class NetEnv(object):
 @util.export
 @util.codegen
 class PackEnv(object):
+    KEEP_ALIVE_INTERVAL = 'PACKAGER/keepAliveInterval'
     YUMPACKAGER_ENABLED = 'PACKAGER/yumpackagerEnabled'
     YUMPACKAGER_EXPIRE_CACHE = 'PACKAGER/yumExpireCache'
-    KEEP_ALIVE_INTERVAL = 'PACKAGER/keepAliveInterval'
     YUM_DISABLED_PLUGINS = 'PACKAGER/yumDisabledPlugins'
     YUM_ENABLED_PLUGINS = 'PACKAGER/yumEnabledPlugins'
     YUM_ROLLBACK = 'PACKAGER/yumRollback'
+    DNFPACKAGER_ENABLED = 'PACKAGER/dnfpackagerEnabled'
+    DNFPACKAGER_EXPIRE_CACHE = 'PACKAGER/dnfExpireCache'
+    DNF_DISABLED_PLUGINS = 'PACKAGER/dnfDisabledPlugins'
+    DNF_ROLLBACK = 'PACKAGER/dnfRollback'
 
 
 @util.export
