@@ -1,4 +1,3 @@
-#!/usr/bin/python
 #
 # otopi -- plugable installer
 # Copyright (C) 2012-2013 Red Hat, Inc.
@@ -22,24 +21,26 @@
 """Minimalist yum API interaction."""
 
 
+import gettext
+import logging
 import os
 import sys
-import logging
 import time
 import traceback
-import gettext
-_ = lambda m: gettext.dgettext(message=m, domain='otopi')
 
 
 import rpmUtils.miscutils
 
 
 import yum
-import yum.rpmtrans
-import yum.callbacks
 import yum.Errors
 import yum.callbacks
 import yum.constants
+import yum.rpmtrans
+
+
+def _(m):
+    return gettext.dgettext(message=m, domain='otopi')
 
 
 class MiniYumSinkBase(object):
@@ -419,14 +420,14 @@ class MiniYum(object):
                 self._sink.verbose('group %s queued' % group)
             except yum.Errors.YumBaseError as e:
                 ret = False
-                self._sink.error(
-                    _('Cannot queue group {group}: {error}').format(
-                        group=group,
-                        error=e
-                    )
+                msg = _('Cannot queue group {group}: {error}').format(
+                    group=group,
+                    error=e
                 )
-
-                if not ignoreErrors:
+                if ignoreErrors:
+                    self._sink.verbose(msg)
+                else:
+                    self._sink.error(msg)
                     raise
 
             except Exception as e:
@@ -528,14 +529,14 @@ class MiniYum(object):
 
                 except (RuntimeError, yum.Errors.YumBaseError) as e:
                     ret = False
-                    self._sink.error(
-                        _('Cannot queue package {package}: {error}').format(
-                            package=package,
-                            error=e
-                        )
+                    msg = _('Cannot queue package {package}: {error}').format(
+                        package=package,
+                        error=e
                     )
-
-                    if not ignoreErrors:
+                    if ignoreErrors:
+                        self._sink.verbose(msg)
+                    else:
+                        self._sink.error(msg)
                         raise
 
                 except Exception as e:
@@ -881,6 +882,22 @@ class MiniYum(object):
             **kwargs
         )
 
+    def installUpdate(self, packages, **kwargs):
+        """Install or update a packages.
+
+        Keyword arguments:
+        packages -- packages to install.
+        ignoreErrors - to ignore errors, will return False
+
+        """
+        return self._queue(
+            'install/update',
+            lambda h: h.available,
+            self._yb.install,   # install does both
+            packages,
+            **kwargs
+        )
+
     def remove(self, packages, **kwargs):
         """Remove packages.
 
