@@ -25,19 +25,23 @@ import builtins
 import datetime
 import errno
 import fcntl
+import gettext
+import os
 import select
 import signal
-import os
 import subprocess
 import time
-import gettext
-_ = lambda m: gettext.dgettext(message=m, domain='otopi')
 
 
 from . import base
+from . import common
 from . import util
 
 
+def _(m):
+    return gettext.dgettext(message=m, domain='otopi')
+
+
 @util.export
 class Stages(object):
     """Stage holder."""
@@ -661,7 +665,7 @@ class PluginBase(base.Base):
                 _("Command '{command}' failed to execute: {error}").format(
                     command=(
                         ' | '.join([
-                            ' '.join([str(a) for a in kw['args']])
+                            ' '.join([common.toStr(a) for a in kw['args']])
                             for kw in popenArgs
                         ])
                     ),
